<?php
/**
 * Class Blog
 *
 * @package WordPress
 * @subpackage achilles
 * @since achilles 1.0
 */
if (!defined('ABSPATH')) {
	exit('Direct script access denied.');
}
if (!class_exists('G5Plus_Inc_Blog')) {
	class G5Plus_Inc_Blog
	{
		
		public $key_post_layout_settings = 'gf_post_layout_settings';
		public $key_feature_post_layout_settings = 'gf_feature_post_layout_settings';
		
		private static $_instance;
		
		public static function getInstance()
		{
			if (self::$_instance == NULL) {
				self::$_instance = new self();
			}
			
			return self::$_instance;
		}
		
		
		public function render_post_thumbnail_markup($args = array())
		{
			$defaults = array(
				'post_id'            => get_the_ID(),
				'image_size'         => 'full',
				'placeholder_enable' => false,
				'display_permalink'  => true,
				'mode'               => 'simple',
				'is_single'          => false,
				'image_mode'         => 'background'
			);
			$defaults = wp_parse_args($args, $defaults);
			g5Theme()->helper()->getTemplate('loop/post-thumbnail', $defaults);
		}
		
		public function render_post_image_markup($args = array())
		{
			$defaults = array(
				'post_id'           => get_the_ID(),
				'image_id'          => '',
				'image_size'        => 'full',
				'gallery_id'        => '',
				'display_permalink' => true,
				'is_single'         => false,
				'image_mode'        => 'background',
				'disable_lazy'      => '0'
			);
			$defaults = wp_parse_args($args, $defaults);
			g5Theme()->helper()->getTemplate('loop/post-image', $defaults);
		}
		
		public function get_image_sizes()
		{
			$image_sizes = array(
				'blog-large'      => '920x520',
				'medium-image-1'  => '190x145',
				'medium-image-2'  => '115x160',
				'medium-image-3'  => '190x330',
				'medium-image-4'  => '115x115',
				'medium-image-5'  => '535x335',
				'medium-image-6'  => '190x260',
				'medium-image-7'  => '303x330',
				'medium-image-8'  => '460x335',
				'medium-image-9'  => '385x330',
				'medium-image-10' => '920x595',
				'medium-image-11' => '190x130',
				'tall-1'          => '535x700',
				'tall-2'          => '460x296',
				'tall-3'          => '650x830',
				'tall-4'          => '995x595',
				'tall-5'          => '995x695',
				'tall-6'          => '765x430',
				'tall-7'          => '1340x695',
				'tall-8'          => '960x720',
				'tall-9'          => '420x535',
				'tall-10'         => '995x620',
				'tall-11'         => '995x680',
				'tall-12'         => '650x710',
				'tall-13'         => '650x695',
				'tall-14'         => '1340x640',
				'tall-15'         => '440x640',
				'tall-16'         => '440x340',
				'tall-17'         => '440x430',
				'tall-18'         => '650x650',
				'tall-19'         => '535x535',
				'tall-20'         => '500x700',
				'tall-21'         => '270x310',
				'tall-22'         => '500x570',
				'tall-23'         => '495x475',
				'large-image-1'   => '535x300',
				'large-image-2'   => '420x270',
				'large-image-3'   => '305x200',
				'large-image-4'   => '880x580',
				'large-image-5'   => '270x230',
				'large-image-6'   => '500x550',
				'large-image-7'   => '305x205',
				'large-image-8'   => '230x180',
				'large-image-9'   => '650x450',
				'large-image-10'  => '420x310',
				'large-image-11'  => '305x235',
				'large-image-12'  => '420x450',
				'large-image-13'  => '224x334',
				'large-image-14'  => '880x575',
				'large-image-15'  => '305x505',
				'large-image-16'  => '345x245',
				'large-image-17'  => '460x300',
				'large-image-18'  => '305x305',
				'large-image-19'  => '230x300',
				'large-image-20'  => '845x470',
				'large-image-21'  => '845x600',
				'list-1'          => '304x410',
				'list-2'          => '115x140',
				'grid-1'          => '535x445',
				'grid-2'          => '575x475',
				'grid-3'          => '765x330',
				'grid-4'          => '385x300',
				'grid-5'          => '420x476',
				'grid-6'          => '954x535',
			
			
			);
			return apply_filters('g5plus_image_sizes', $image_sizes);
		}
		
		public function pagination_markup()
		{
			global $gsf_query;
			if (!isset($gsf_query)) return;
			$settings = &$this->get_layout_settings();
			$post_paging = $settings['post_paging'];
			if (($gsf_query->max_num_pages > 1) && ($post_paging !== '') && ($post_paging !== 'none')) {
				
				if (!isset($settings['settingId']) || $settings['settingId'] === '') {
					$settingId = mt_rand();
				} else {
					$settingId = $settings['settingId'];
				}
				
				if (!isset($settings['pagenum_link']) || $settings['pagenum_link'] === '') {
					$pagenum_link = html_entity_decode(get_pagenum_link());
					$settings['pagenum_link'] = $pagenum_link;
				} else {
					$pagenum_link = $settings['pagenum_link'];
				}
				
				if (($post_paging !== 'pagination') && (!isset($_REQUEST['action']) || empty($_REQUEST['action']))) {
					
					$query_args = array();
					if (is_home()) {
						$query_args['is_home'] = true;
					}
					g5Theme()->custom_js()->addJsVariable(array(
						'settings' => $settings,
						'query'    => g5Theme()->query()->get_ajax_query_vars($query_args)
					), "gf_ajax_paginate_{$settingId}");
				}
				
				g5Theme()->helper()->getTemplate("paging/{$post_paging}", array('settingId' => $settingId, 'pagenum_link' => $pagenum_link));
			}
		}
		
		public function category_filter_markup()
		{
			$settings = &$this->get_layout_settings();
			if (!isset($settings['settingId']) || $settings['settingId'] === '') {
				$settingId = mt_rand();
			} else {
				$settingId = $settings['settingId'];
			}
			if (!isset($settings['pagenum_link']) || $settings['pagenum_link'] === '') {
				$pagenum_link = html_entity_decode(get_pagenum_link());
				$settings['pagenum_link'] = $pagenum_link;
			} else {
				$pagenum_link = $settings['pagenum_link'];
			}
			
			
			if (!isset($_REQUEST['action']) || empty($_REQUEST['action'])) {
				$query_args = array();
				if (is_home()) {
					$query_args['is_home'] = true;
				}
				
				g5Theme()->custom_js()->addJsVariable(array(
					'settings' => $settings,
					'query'    => g5Theme()->query()->get_ajax_query_vars($query_args)
				), "gf_ajax_paginate_{$settingId}");
			}
			g5Theme()->helper()->getTemplate("loop/cat-filter", array(
				'settingId'       => $settingId,
				'pagenum_link'    => $pagenum_link,
				'post_type'       => $settings['post_type'],
				'taxonomy'        => isset($settings['taxonomy']) ? $settings['taxonomy'] : 'category',
				'category_filter' => isset($settings['cat']) ? $settings['cat'] : '',
				'current_cat'     => isset($settings['current_cat']) ? $settings['current_cat'] : -1,
				'filter_vertical' => isset($settings['category_filter_vertical']) ? $settings['category_filter_vertical'] : false,
				'filter_type'     => isset($settings['category_filter_type']) ? $settings['category_filter_type'] : ''
			));
		}
		
		public function tabs_markup()
		{
			$settings = &$this->get_layout_settings();
			$tabs = isset($settings['tabs']) ? $settings['tabs'] : array();
			unset($settings['tabs']);
			if (!isset($_REQUEST['action']) || empty($_REQUEST['action'])) {
				$index = 1;
				foreach ($tabs as &$tab) {
					$settingId = mt_rand();
					$query_args = $tab['query_args'];
					$tab['settingId'] = $settingId;
					if ($index === 1) {
						$settings['settingId'] = $settingId;
					}
					
					if (is_home()) {
						$query_args['is_home'] = true;
					}
					g5Theme()->custom_js()->addJsVariable(array(
						'settings' => $settings,
						'query'    => g5Theme()->query()->get_ajax_query_vars($query_args)
					), "gf_ajax_paginate_{$settingId}");
					$index++;
				}
			}
			g5Theme()->helper()->getTemplate("loop/tabs", array('tabs' => $tabs));
		}
		
		
		/**
		 * Get Post Layout Settings
		 *
		 * @return mixed
		 */
		public function &get_layout_settings()
		{
			if (isset($GLOBALS[$this->key_post_layout_settings]) && is_array($GLOBALS[$this->key_post_layout_settings])) {
				return $GLOBALS[$this->key_post_layout_settings];
			}
			
			$GLOBALS[$this->key_post_layout_settings] = array(
				'post_layout'            => g5Theme()->options()->get_post_layout(),
				'post_columns'           => array(
					'lg' => intval(g5Theme()->options()->get_post_columns()),
					'md' => intval(g5Theme()->options()->get_post_columns_md()),
					'sm' => intval(g5Theme()->options()->get_post_columns_sm()),
					'xs' => intval(g5Theme()->options()->get_post_columns_xs()),
				),
				'post_columns_gutter'    => intval(g5Theme()->options()->get_post_columns_gutter()),
				'post_paging'            => g5Theme()->options()->get_post_paging(),
				'posts_per_page'         => intval(g5Theme()->options()->get_posts_per_page()),
				'post_animation'         => g5Theme()->options()->get_post_animation(),
				'itemSelector'           => 'article',
				'category_filter_enable' => false,
				'post_type'              => 'post'
			);
			return $GLOBALS[$this->key_post_layout_settings];
		}
		
		public function unset_layout_settings()
		{
			unset($GLOBALS[$this->key_post_layout_settings]);
		}
		
		/**
		 * Set Post Layout Settings
		 *
		 * @param $args
		 */
		public function set_layout_settings($args)
		{
			$post_settings = &$this->get_layout_settings();
			$post_settings = wp_parse_args($args, $post_settings);
		}
		
		public function archive_markup($query_args = null, $settings = null)
		{
			if (isset($settings['tabs']) && isset($settings['tabs'][0]['query_args'])) {
				$query_args = $settings['tabs'][0]['query_args'];
			}
			
			if (!isset($query_args)) {
				$settings['isMainQuery'] = true;
			}
			
			if (isset($settings) && (sizeof($settings) > 0)) {
				$this->set_layout_settings($settings);
			}
			
			$query_args = g5Theme()->query()->get_main_query_vars($query_args);
			g5Theme()->query()->query_posts($query_args);
			
			
			if (isset($settings['category_filter_enable']) && $settings['category_filter_enable'] === true) {
				add_action('g5plus_before_archive_wrapper', array($this, 'category_filter_markup'));
			}
			
			if (isset($settings['tabs'])) {
				add_action('g5plus_before_archive_wrapper', array($this, 'tabs_markup'));
			}
			
			g5Theme()->helper()->getTemplate('archive');
			
			if (isset($settings['tabs'])) {
				remove_action('g5plus_before_archive_wrapper', array($this, 'tabs_markup'));
			}
			
			if (isset($settings['category_filter_enable']) && $settings['category_filter_enable'] === true) {
				remove_action('g5plus_before_archive_wrapper', array($this, 'category_filter_markup'));
			}
			
			if (isset($settings) && (sizeof($settings) > 0)) {
				$this->unset_layout_settings();
			}
			
			g5Theme()->query()->reset_query();
			
		}
		
		public function cat_badge_markup($args = array())
		{
			$default = array(
				'highlight' => false
			);
			$args = wp_parse_args($args, $default);
			g5Theme()->helper()->getTemplate('loop/cat-badge', $args);
		}
		
		/**
		 * Get Primary Category
		 *
		 * @return array|mixed|null|object|WP_Error
		 */
		public function get_primary_cat()
		{
			// Primary category from Yoast SEO plugin
			if (class_exists('WPSEO_Primary_Term')) {
				$prim_cat = get_post_meta(get_the_ID(), '_yoast_wpseo_primary_category', true);
				if ($prim_cat) {
					$prim_cat = get_category($prim_cat);
					if (!is_wp_error($prim_cat)) {
						return $prim_cat;
					}
				}
			}
			
			global $wp_query;
			$prim_cat = intval($wp_query->get('gf_cat', -1));
			if ($prim_cat > 0) {
				$prim_cat = get_category($prim_cat);
				if (!is_wp_error($prim_cat)) {
					return $prim_cat;
				}
			}
			
			$category__in = $wp_query->get('category__in', array());
			if (sizeof($category__in) > 0) {
				$categories = get_the_category();
				for ($i = 0; $i < sizeof($categories); $i++) {
					if (!in_array($categories[$i]->term_id, $category__in)) {
						unset($categories[$i]);
					}
				}
				if (sizeof($categories) > 0) {
					return current($categories);
				}
				
			}
			
			// First cat
			return current(get_the_category());
		}
		
		public function archive_ads_markup($args)
		{
			g5Theme()->helper()->getTemplate('loop/ads', $args);
		}
		
		public function get_layout_matrix($layout = 'large-image')
		{
			$post_settings = &g5Theme()->blog()->get_layout_settings();
			
			$columns = isset($post_settings['post_columns']) ? $post_settings['post_columns'] : array(
				'lg' => 2,
				'md' => 2,
				'sm' => 1,
				'xs' => 1
			);
			$columns = g5Theme()->helper()->get_bootstrap_columns($columns);
			$columns_gutter = intval(isset($post_settings['post_columns_gutter']) ? $post_settings['post_columns_gutter'] : 40);
			$matrix = array(
				//post content layout
				'large-image'    => array(
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-xs-12', 'template' => 'large-image-1', 'image_size' => 'blog-large'),
					)
				),
				'grid-image'     => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => $columns, 'template' => 'large-image-1', 'image_size' => 'large-image-17'),
					)
				),
				'grid-image-2'   => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => $columns, 'template' => 'large-image-6', 'image_size' => 'large-image-11'),
					)
				),
				'grid-image-3'   => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => $columns, 'template' => 'large-image-5', 'image_size' => 'large-image-7'),
					)
				),
				'medium-image-1' => array(
					'columns_gutter'     => 30,
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-xs-12', 'template' => 'medium-image-6', 'image_size' => 'medium-image-8'),
					)
				),
				'medium-image-2' => array(
					'columns_gutter'     => 40,
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-xs-12', 'template' => 'medium-image-15', 'image_size' => 'medium-image-9'),
					)
				),
				'medium-image-3' => array(
					'columns_gutter'     => 40,
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-xs-12', 'template' => 'medium-image-16', 'image_size' => 'medium-image-9'),
					)
				),
				'medium-image-4' => array(
					'columns_gutter'     => 30,
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-xs-12', 'template' => 'medium-image-17', 'image_size' => 'large-image-1'),
					)
				),
				'zigzac-image'   => array(
					'columns_gutter'     => 30,
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-xs-12', 'template' => 'medium-image-6', 'image_size' => 'medium-image-8'),
						array('columns' => 'col-xs-12', 'template' => 'medium-image-17', 'image_size' => 'medium-image-8'),
					)
				),
				'masonry-image'  => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'masonry',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => $columns, 'template' => 'large-image-12', 'image_size' => 'large-image-18'),
					)
				),
				//relate layout
				'large-image-3'  => array(
					'columns_gutter' => $columns_gutter,
					'isotope'        => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'layout'         => array(
						array('columns' => $columns, 'template' => 'large-image-3', 'image_size' => 'large-image-3')
					)
				),
				'large-image-5'  => array(
					'columns_gutter' => $columns_gutter,
					'isotope'        => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'layout'         => array(
						array('columns' => $columns, 'template' => 'large-image-5', 'image_size' => 'large-image-7')
					)
				),
				'large-image-6'  => array(
					'columns_gutter' => $columns_gutter,
					'isotope'        => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'layout'         => array(
						array('columns' => $columns, 'template' => 'large-image-6', 'image_size' => 'large-image-19')
					)
				),
				//shortcode post
				'grid-1'         => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => $columns, 'template' => 'medium-image-1', 'image_size' => 'medium-image-1'),
					)
				),
				'large-1'        => array(
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-xs-12', 'template' => 'large-image-10', 'image_size' => 'large-image-13', 'isFirst' => true),
						array('columns' => 'col-xs-12', 'template' => 'list-1', 'image_size' => ''),
					)
				),
				'large-2'        => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-xs-12', 'template' => 'large-image-1', 'image_size' => 'large-image-1'),
					)
				),
				'large-3'        => array(
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-xs-12', 'template' => 'large-image-10', 'image_size' => 'large-image-13', 'isFirst' => true),
						array('columns' => 'col-xs-12', 'template' => 'list-1', 'image_size' => ''),
					)
				),
				'large-4'        => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-xs-12', 'template' => 'large-image-4', 'image_size' => 'large-image-5'),
					)
				),
				'large-5'        => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-xs-12', 'template' => 'large-image-7', 'image_size' => 'large-image-6'),
					)
				),
				'large-6'        => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-xs-12', 'template' => 'large-image-3', 'image_size' => 'large-image-3'),
					)
				),
				'list-1'         => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-xs-12', 'template' => 'list-2', 'image_size' => ''),
					)
				),
				'list-2'         => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-xs-12', 'template' => 'list-3', 'image_size' => ''),
					)
				),
				'list-3'         => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-xs-12', 'template' => 'list-4', 'image_size' => ''),
					)
				),
				'medium-1'       => array(
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-xs-12', 'template' => 'medium-image-8', 'image_size' => 'list-2', 'isFirst' => true),
						array('columns' => 'col-xs-12', 'template' => 'list-1', 'image_size' => ''),
					)
				),
				'medium-2'       => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => $columns, 'template' => 'medium-image-2', 'image_size' => 'medium-image-3'),
					)
				),
				'medium-3'       => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-xs-12', 'template' => 'medium-image-10', 'image_size' => 'medium-image-4'),
					)
				),
				'medium-4'       => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-xs-12', 'template' => 'medium-image-6', 'image_size' => 'medium-image-5'),
					)
				),
				'medium-5'       => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-xs-12', 'template' => 'medium-image-13', 'image_size' => 'medium-image-7'),
					)
				),
				'small-1'        => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-xs-12', 'template' => 'medium-image-4', 'image_size' => 'medium-image-11'),
					)
				),
				'mix-1'          => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-xs-12', 'template' => 'tall-2', 'image_size' => 'tall-1', 'isFirst' => true),
						array('columns' => 'col-xs-12', 'template' => 'large-image-1', 'image_size' => 'large-image-1'),
					)
				),
				'mix-2'          => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-xs-12', 'template' => 'large-image-2', 'image_size' => 'large-image-2', 'isFirst' => true),
						array('columns' => 'col-xs-12', 'template' => 'medium-image-9', 'image_size' => 'medium-image-2'),
					)
				),
				'mix-3'          => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-md-6 col-sm-6 col-xs-12', 'template' => 'grid-1', 'image_size' => 'grid-1', 'isFirst' => true),
						array('columns' => 'col-md-6 col-sm-6 col-xs-12', 'template' => 'grid-1', 'image_size' => 'grid-1', 'isFirst' => true),
						array('columns' => 'col-md-4 col-sm-6 col-xs-12', 'template' => 'medium-image-3', 'image_size' => 'medium-image-2'),
					)
				),
				'mix-4'          => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'masonry',
						'masonry'      => array(
							'columnWidth' => '.col-lg-4'
						)
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-lg-8 col-md-12 col-xs-12', 'template' => 'large-image-1', 'image_size' => 'large-image-4', 'isFirst' => true),
						array('columns' => 'col-lg-4 col-md-6 col-sm-6 col-xs-12', 'template' => 'medium-image-4', 'image_size' => 'medium-image-11'),
					)
				),
				'mix-5'          => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'masonry',
						'masonry'      => array(
							'columnWidth' => '.col-md-4'
						)
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-md-8 col-sm-12 col-xs-12', 'template' => 'tall-3', 'image_size' => 'tall-3', 'isFirst' => true),
						array('columns' => 'col-md-4 col-sm-4 col-xs-12', 'template' => 'large-image-5', 'image_size' => 'large-image-7', 'isFirst' => true),
						array('columns' => 'col-md-4 col-sm-4 col-xs-12', 'template' => 'large-image-5', 'image_size' => 'large-image-7', 'isFirst' => true),
						array('columns' => 'col-md-4 col-sm-4 col-xs-12', 'template' => 'large-image-5', 'image_size' => 'large-image-7', 'isFirst' => true),
						array('columns' => 'col-md-4 col-sm-6 col-xs-12', 'template' => 'medium-image-5', 'image_size' => 'medium-image-2'),
					)
				),
				'mix-6'          => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'masonry',
						'masonry'      => array(
							'columnWidth' => '.col-md-4'
						)
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-md-8 col-xs-12', 'template' => 'grid-1', 'image_size' => 'grid-2', 'isFirst' => true),
						array('columns' => 'col-md-4 col-sm-6 col-xs-12', 'template' => 'large-image-4', 'image_size' => 'large-image-8'),
					)
				),
				'mix-7'          => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-md-12 col-xs-12', 'template' => 'grid-2', 'image_size' => 'grid-3', 'isFirst' => true),
						array('columns' => 'col-md-6 col-sm-6 col-xs-12', 'template' => 'medium-image-7', 'image_size' => 'medium-image-2'),
					)
				),
				'mix-8'          => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-md-12 col-xs-12', 'template' => 'tall-5', 'image_size' => 'tall-4', 'isFirst' => true),
						array('columns' => 'col-md-6 col-sm-6 col-xs-12', 'template' => 'medium-image-8', 'image_size' => 'medium-image-11'),
					)
				),
				'mix-9'          => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-md-12 col-xs-12', 'template' => 'tall-11', 'image_size' => 'tall-5', 'isFirst' => true),
						array('columns' => 'col-md-4 col-sm-4 col-xs-12', 'template' => 'large-image-5', 'image_size' => 'large-image-7'),
					)
				),
				'mix-10'         => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-md-12 col-xs-12', 'template' => 'medium-image-11', 'image_size' => 'grid-2', 'isFirst' => true),
						array('columns' => 'col-md-6 col-sm-6 col-xs-12', 'template' => 'medium-image-7', 'image_size' => 'medium-image-2'),
					)
				),
				'mix-11'         => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'masonry',
						'masonry'      => array(
							'columnWidth' => '.col-md-4'
						)
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-md-8 col-sm-12 col-xs-12', 'template' => 'large-image-1', 'image_size' => 'large-image-9', 'isFirst' => true),
						array('columns' => 'col-md-4 col-sm-6 col-xs-12', 'template' => 'medium-image-5', 'image_size' => 'medium-image-2'),
					)
				),
				'mix-12'         => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'masonry',
						'masonry'      => array(
							'columnWidth' => '.gsf-col-base'
						)
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-md-5 col-sm-6 col-xs-12', 'template' => 'large-image-1', 'image_size' => 'large-image-10', 'isFirst' => true),
						array('columns' => 'col-md-4 col-sm-6 col-xs-12', 'template' => 'large-image-6', 'image_size' => 'large-image-11', 'isFirst' => true),
						array('columns' => 'col-md-3 col-sm-6 col-xs-12', 'template' => 'list-2', 'image_size' => ''),
					)
				),
				'mix-14'         => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'masonry',
						'masonry'      => array(
							'columnWidth' => '.col-sm-6'
						)
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-md-8 col-sm-12 col-xs-12', 'template' => 'tall-6', 'image_size' => 'tall-6', 'isFirst' => true),
						array('columns' => 'col-md-4 col-sm-6 col-xs-12', 'template' => 'medium-image-3', 'image_size' => 'medium-image-2'),
					)
				),
				'mix-15'         => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'masonry',
						'masonry'      => array(
							'columnWidth' => '.col-lg-4'
						)
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-lg-8 col-md-12 col-sm-12 col-xs-12', 'template' => 'tall-6', 'image_size' => 'large-image-4', 'isFirst' => true),
						array('columns' => 'col-lg-4 col-md-6 col-sm-6 col-xs-12', 'template' => 'medium-image-4', 'image_size' => 'medium-image-11'),
					)
				),
				'mix-16'         => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-md-12 col-sm-12 col-xs-12', 'template' => 'grid-1', 'image_size' => 'medium-image-9', 'isFirst' => true),
						array('columns' => 'col-md-12 col-sm-12 col-xs-12', 'template' => 'medium-image-4', 'image_size' => 'medium-image-2'),
					)
				),
				'mix-17'         => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-md-12 col-sm-12 col-xs-12', 'template' => 'tall-7', 'image_size' => 'tall-19', 'isFirst' => true),
						array('columns' => 'col-md-12 col-sm-12 col-xs-12', 'template' => 'list-2', 'image_size' => 'medium-image-2'),
					)
				),
				'mix-18'         => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-md-12 col-sm-12 col-xs-12', 'template' => 'large-image-8', 'image_size' => 'large-image-2', 'isFirst' => true),
						array('columns' => 'col-md-12 col-sm-12 col-xs-12', 'template' => 'medium-image-12', 'image_size' => 'medium-image-6'),
					)
				),
				'mix-19'         => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-md-12 col-sm-12 col-xs-12', 'template' => 'large-image-1', 'image_size' => 'large-image-12', 'isFirst' => true),
						array('columns' => 'col-md-12 col-sm-12 col-xs-12', 'template' => 'medium-image-4', 'image_size' => 'medium-image-2'),
					)
				),
				'mix-21'         => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-md-12 col-sm-12 col-xs-12', 'template' => 'tall-8', 'image_size' => 'tall-9', 'isFirst' => true),
						array('columns' => 'col-md-12 col-sm-12 col-xs-12', 'template' => 'list-2', 'image_size' => ''),
					)
				),
				'mix-22'         => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-md-12 col-sm-12 col-xs-12', 'template' => 'large-image-5', 'image_size' => 'large-image-3', 'isFirst' => true),
						array('columns' => 'col-md-12 col-sm-12 col-xs-12', 'template' => 'list-2', 'image_size' => ''),
					)
				),
				'mix-24'         => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-md-11 col-sm-11 col-xs-12', 'template' => 'large-image-13', 'image_size' => 'large-image-20'),
						array('columns' => 'col-md-6 col-sm-6 col-xs-12', 'template' => 'large-image-13', 'image_size' => 'tall-20'),
						array('columns' => 'col-md-offset-1 col-sm-offset-1 col-md-3 col-sm-3 col-xs-12', 'template' => 'large-image-14', 'image_size' => 'tall-21'),
						array('columns' => 'col-md-offset-1 col-sm-offset-1 col-md-11 col-sm-11 col-xs-12', 'template' => 'large-image-13', 'image_size' => 'large-image-21'),
						array('columns' => 'col-md-offset-3 col-sm-offset-3 col-md-6 col-sm-6 col-xs-12', 'template' => 'large-image-13', 'image_size' => 'tall-22'),
					)
				),
				'mix-25'          => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'masonry',
						'masonry'      => array(
							'columnWidth' => '.col-md-4'
						)
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-md-8 col-xs-12', 'template' => 'grid-1', 'image_size' => 'tall-23', 'isFirst' => true),
						array('columns' => 'col-md-4 col-sm-6 col-xs-12', 'template' => 'large-image-4', 'image_size' => 'large-image-8'),
					)
				),
				'tall-1'         => array(
					'columns_gutter'     => $columns_gutter,
					'isotope'            => array(
						'itemSelector' => 'article',
						'layoutMode'   => 'fitRows',
					),
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-md-12 col-sm-12 col-xs-12', 'template' => 'tall-1', 'image_size' => 'tall-2', 'isFirst' => true),
						array('columns' => 'col-md-12 col-sm-12 col-xs-12', 'template' => 'list-1', 'image_size' => ''),
					)
				),
				'tall-3'         => array(
					'columns_gutter'     => $columns_gutter,
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-md-12 col-sm-12 col-xs-12', 'template' => 'tall-9', 'image_size' => 'tall-7'),
					)
				),
				'tall-4'         => array(
					'columns_gutter'     => $columns_gutter,
					'placeholder_enable' => false,
					'layout'             => array(
						array('columns' => 'col-md-12 col-sm-12 col-xs-12', 'template' => 'tall-10', 'image_size' => 'tall-8'),
					)
				),
			);
			if (!isset($matrix[$layout])) return $matrix['medium-image-1'];
			return $matrix[$layout];
		}
		
		
		public function get_list_comments_args($args = array())
		{
			// Default arguments for listing comments.
			$defaults = array(
				'style'       => 'ol',
				'short_ping'  => true,
				'avatar_size' => 40,
				'callback'    => 'g5plus_comments_callback',
			);
			// Filter default arguments to enable developers to change it. also return it.
			return apply_filters('g5plus_list_comments_args', wp_parse_args($args, $defaults));
		}
		
		public function get_comments_form_args($args = array())
		{
			$commenter = wp_get_current_commenter();
			$req = get_option('require_name_email');
			$aria_req = ($req ? " aria-required='true'" : '');
			$html_req = ($req ? " required='required'" : '');
			$html5 = true;
			$fields = array(
				'author' => '<p class="comment-form-author">' . '<label for="author">' . esc_html__('Name', 'g5plus-achilles') . ($req ? ' <span class="required">*</span>' : '') . '</label> ' .
					'<input placeholder="' . esc_html__('Name', 'g5plus-achilles') . '" id="author" name="author" type="text" value="' . esc_attr($commenter['comment_author']) . '" size="30" maxlength="245"' . $aria_req . $html_req . ' /></p>',
				'email'  => '<p class="comment-form-email"><label for="email">' . esc_html__('Email', 'g5plus-achilles') . ($req ? ' <span class="required">*</span>' : '') . '</label> ' .
					'<input placeholder="' . esc_html__('Email', 'g5plus-achilles') . '" id="email" name="email" ' . ($html5 ? 'type="email"' : 'type="text"') . ' value="' . esc_attr($commenter['comment_author_email']) . '" size="30" maxlength="100" aria-describedby="email-notes"' . $aria_req . $html_req . ' /></p>',
				'url'    => '<p class="comment-form-url"><label for="url">' . esc_html__('Website', 'g5plus-achilles') . '</label> ' .
					'<input id="url" placeholder="' . esc_html__('Website', 'g5plus-achilles') . '" name="url" ' . ($html5 ? 'type="url"' : 'type="text"') . ' value="' . esc_attr($commenter['comment_author_url']) . '" size="30" maxlength="200" /></p>',
			);
			
			
			$defaults = array(
				'fields'             => $fields,
				'comment_field'      => '<p class="comment-form-comment"><label for="comment">' . esc_html__('Comment', 'g5plus-achilles') . '</label> <textarea placeholder="' . esc_html__('Comment', 'g5plus-achilles') . '" id="comment" name="comment" cols="45" rows="8" maxlength="65525" aria-required="true" required="required"></textarea></p>',
				'title_reply'        => esc_html__('Comment', 'g5plus-achilles'),
				'title_reply_to'     => esc_html__('Comment to %s', 'g5plus-achilles'),
				'title_reply_before' => '<h4 id="reply-title" class="gf-heading-title"><span class="accent-color fw-bold text-normal">' . esc_html__('Leave a ', 'g5plus-achilles') . '</span>',
				'title_reply_after'  => '</h4>',
				'label_submit'       => esc_html__('Post Comment', 'g5plus-achilles'),
				'class_submit'       => 'btn btn-lg btn-block'
			);
			
			// Filter default arguments to enable developers to change it. also return it.
			return apply_filters('g5plus_comments_form_args', wp_parse_args($args, $defaults));
		}
		
		public function wpb_move_comment_field_to_bottom($fields)
		{
			$comment_field = $fields['comment'];
			unset($fields['comment']);
			$fields['comment'] = $comment_field;
			return $fields;
		}
	}
}